CryptoError

Enum CryptoError 

#[non_exhaustive]
pub enum CryptoError { NoDefaultProvider, UnsupportedAlgorithm(CryptoAlgorithm), InvalidKeyLength { expected: usize, actual: usize, }, InvalidNonceLength { expected: usize, actual: usize, }, InvalidTagLength { expected: usize, actual: usize, }, InvalidPublicKey, InvalidPrivateKey, AuthenticationFailed, InvalidSignature, RandomnessFailed, OutputTooSmall { required: usize, actual: usize, }, Provider(String), }
A provider-neutral cryptographic failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NoDefaultProvider

No built-in default provider was compiled.



UnsupportedAlgorithm(CryptoAlgorithm)

The provider does not implement an algorithm.



InvalidKeyLength

A key has the wrong length.

Fields

expected: usize

Required length.

actual: usize

Supplied length.



InvalidNonceLength

A nonce or IV has the wrong length.

Fields

expected: usize

Required length.

actual: usize

Supplied length.



InvalidTagLength

An authentication tag has the wrong length.

Fields

expected: usize

Required length.

actual: usize

Supplied length.



InvalidPublicKey

Public-key bytes are malformed or use the wrong encoding.



InvalidPrivateKey

Private-key bytes are malformed or incompatible with the scheme.



AuthenticationFailed

Decryption, padding, or tag authentication failed.



InvalidSignature

Signature verification failed.



RandomnessFailed

The cryptographically secure random source failed.



OutputTooSmall

A caller-owned output buffer is too small.

Fields

required: usize

Required length.

actual: usize

Supplied length.



Provider(String)

Sanitized provider diagnostic context.