pub trait StreamCipher: Send {
// Required method
fn apply_keystream(
&mut self,
iv: &[u8],
data: &mut [u8],
) -> Result<(), CryptoError>;
}Expand description
A keyed stream cipher with a reusable expanded key.
Required Methods
Sourcefn apply_keystream(
&mut self,
iv: &[u8],
data: &mut [u8],
) -> Result<(), CryptoError>
fn apply_keystream( &mut self, iv: &[u8], data: &mut [u8], ) -> Result<(), CryptoError>
Applies the keystream in place with a fresh IV.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".